@@ -8,11 +8,12 @@
 
 namespace dynamicgraph {
 
-template <typename Ent> struct EntityHelper {
+template <typename Ent>
+struct EntityHelper {
   typedef Ent EntityClassName;
   // static const std::string CLASS_NAME; TO BE ADDED IN DG DIRECTLY
 };
 
-} // namespace dynamicgraph
+}  // namespace dynamicgraph
 
-#endif // __sot_core_entity_helper_H__
+#endif  // __sot_core_entity_helper_H__
